@@ -1,244 +1,282 @@
-( cd usr/share/doc/HTML/ru/kppp ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kppp ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/dragonplayer ; rm -rf common )
-( cd usr/share/doc/HTML/ru/dragonplayer ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kbounce ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kbounce ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kopete ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kopete ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kwrite ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kwrite ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kmplot ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kmplot ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kteatime ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kteatime ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/knetattach ; rm -rf common )
-( cd usr/share/doc/HTML/ru/knetattach ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/konsole ; rm -rf common )
-( cd usr/share/doc/HTML/ru/konsole ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kolf ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kolf ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/krfb ; rm -rf common )
-( cd usr/share/doc/HTML/ru/krfb ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kget ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kget ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kreversi ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kreversi ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kshisen ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kshisen ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/klettres ; rm -rf common )
+( cd usr/share/doc/HTML/ru/klettres ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kontact ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kontact ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/klines ; rm -rf common )
+( cd usr/share/doc/HTML/ru/klines ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/gwenview ; rm -rf common )
+( cd usr/share/doc/HTML/ru/gwenview ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/klipper ; rm -rf common )
+( cd usr/share/doc/HTML/ru/klipper ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kdesu ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kdesu ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kuser ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kuser ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/kcmcss ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/kcmcss ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/cache ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/cache ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/clock ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/clock ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/ebrowsing ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/ebrowsing ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kspaceduel ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kspaceduel ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kdm ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kdm ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/konsole ; rm -rf common )
+( cd usr/share/doc/HTML/ru/konsole ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/dragonplayer ; rm -rf common )
+( cd usr/share/doc/HTML/ru/dragonplayer ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/ktuberling ; rm -rf common )
+( cd usr/share/doc/HTML/ru/ktuberling ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kfind ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kfind ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kpat ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kpat ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kalzium ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kalzium ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/amor ; rm -rf common )
+( cd usr/share/doc/HTML/ru/amor ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/akregator ; rm -rf common )
+( cd usr/share/doc/HTML/ru/akregator ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kmix ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kmix ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/lokalize ; rm -rf common )
+( cd usr/share/doc/HTML/ru/lokalize ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kwatchgnupg ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kwatchgnupg ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/ksnapshot ; rm -rf common )
+( cd usr/share/doc/HTML/ru/ksnapshot ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/marble ; rm -rf common )
+( cd usr/share/doc/HTML/ru/marble ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/cantor ; rm -rf common )
+( cd usr/share/doc/HTML/ru/cantor ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kig ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kig ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kwrite ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kwrite ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kjumpingcube ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kjumpingcube ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kppp ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kppp ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kruler ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kruler ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kjots ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kjots ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/blinken ; rm -rf common )
+( cd usr/share/doc/HTML/ru/blinken ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/file ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/file ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/rlogin ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/tar ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/tar ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/finger ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/finger ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/imap ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/imap ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/floppy ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/floppy ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/mbox ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/mbox ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/mailto ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/mailto ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/sftp ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/sftp ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/telnet ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/telnet ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/pop3 ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/pop3 ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/gzip ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/gzip ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/news ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/news ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/thumbnail ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/thumbnail ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/audiocd ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/audiocd ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/smtp ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/smtp ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/nfs ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/nfs ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/ldap ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/ldap ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/help ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/help ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/data ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/data ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/info ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/info ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/nntp ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/nntp ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/ftp ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/ftp ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/webdav ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/webdav ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kioslave/sieve ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kioslave/sieve ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcron ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcron ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kstars ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kstars ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kgeography ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kgeography ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kmenuedit ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kmenuedit ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/ksysguard ; rm -rf common )
+( cd usr/share/doc/HTML/ru/ksysguard ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/korganizer ; rm -rf common )
+( cd usr/share/doc/HTML/ru/korganizer ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/ark ; rm -rf common )
+( cd usr/share/doc/HTML/ru/ark ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kbounce ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kbounce ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kigo ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kigo ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/juk ; rm -rf common )
+( cd usr/share/doc/HTML/ru/juk ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcalc ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcalc ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kbattleship ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kbattleship ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/palapeli ; rm -rf common )
+( cd usr/share/doc/HTML/ru/palapeli ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcharselect ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcharselect ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/cervisia ; rm -rf common )
+( cd usr/share/doc/HTML/ru/cervisia ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kolourpaint ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kolourpaint ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kturtle ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kturtle ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kwallet ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kwallet ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/cookies ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/cookies ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kcontrol/screensaver ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kcontrol/screensaver ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/windowspecific ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/windowspecific ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/fontinst ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/fontinst ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kcontrol/spellchecking ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kcontrol/spellchecking ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/smb ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/smb ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kcontrol/icons ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kcontrol/icons ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/autostart ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/autostart ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/language ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/language ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/netpref ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/netpref ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/kcmsmserver ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/kcmsmserver ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/keyboard ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/keyboard ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/performance ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/performance ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/filetypes ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/filetypes ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kcontrol/bell ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kcontrol/bell ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kcontrol/proxy ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kcontrol/proxy ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/smb ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/smb ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/netpref ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/netpref ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/kcmsmserver ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/kcmsmserver ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/language ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/language ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/kcmcss ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/kcmcss ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/keyboard ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/keyboard ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/colors ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/colors ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/kremotecontrol ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/kremotecontrol ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kcontrol/kcmnotify ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kcontrol/kcmnotify ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kcontrol/keys ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kcontrol/keys ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/clock ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/clock ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/autostart ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/autostart ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kcontrol/useragent ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kcontrol/useragent ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/cookies ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/cookies ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/kcmlaunch ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/kcmlaunch ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcontrol/colors ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcontrol/colors ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/ebrowsing ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/ebrowsing ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/cache ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/cache ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kcontrol/filemanager ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kcontrol/filemanager ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kmenuedit ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kmenuedit ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kwordquiz ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kwordquiz ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/amor ; rm -rf common )
-( cd usr/share/doc/HTML/ru/amor ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/ktouch ; rm -rf common )
-( cd usr/share/doc/HTML/ru/ktouch ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kmousetool ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kmousetool ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/klines ; rm -rf common )
-( cd usr/share/doc/HTML/ru/klines ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/telnet ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/telnet ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/sftp ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/sftp ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/mailto ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/mailto ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/nfs ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/nfs ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/finger ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/finger ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/gzip ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/gzip ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/file ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/file ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/nntp ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/nntp ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/audiocd ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/audiocd ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/thumbnail ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/thumbnail ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/floppy ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/floppy ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/ftp ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/ftp ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/data ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/data ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/tar ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/tar ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/rlogin ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/info ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/info ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/help ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/help ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/webdav ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/webdav ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/ldap ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/ldap ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kioslave/smtp ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kioslave/smtp ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kompare ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kompare ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/ktuberling ; rm -rf common )
-( cd usr/share/doc/HTML/ru/ktuberling ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/konquest ; rm -rf common )
-( cd usr/share/doc/HTML/ru/konquest ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kstars ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kstars ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kinfocenter ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kinfocenter ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kanagram ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kanagram ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/blinken ; rm -rf common )
-( cd usr/share/doc/HTML/ru/blinken ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/gwenview ; rm -rf common )
-( cd usr/share/doc/HTML/ru/gwenview ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kspaceduel ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kspaceduel ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kjumpingcube ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kjumpingcube ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kshisen ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kshisen ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kdebugdialog ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kdebugdialog ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/ksnapshot ; rm -rf common )
-( cd usr/share/doc/HTML/ru/ksnapshot ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kruler ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kruler ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/krdc ; rm -rf common )
-( cd usr/share/doc/HTML/ru/krdc ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kolourpaint ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kolourpaint ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kfloppy ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kfloppy ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kalzium ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kalzium ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/ktimer ; rm -rf common )
-( cd usr/share/doc/HTML/ru/ktimer ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/klipper ; rm -rf common )
-( cd usr/share/doc/HTML/ru/klipper ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/konqueror ; rm -rf common )
-( cd usr/share/doc/HTML/ru/konqueror ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kdm ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kdm ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/klettres ; rm -rf common )
-( cd usr/share/doc/HTML/ru/klettres ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/lokalize ; rm -rf common )
-( cd usr/share/doc/HTML/ru/lokalize ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcalc ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcalc ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kig ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kig ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kmix ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kmix ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kwallet ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kwallet ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/cantor ; rm -rf common )
-( cd usr/share/doc/HTML/ru/cantor ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/cervisia ; rm -rf common )
-( cd usr/share/doc/HTML/ru/cervisia ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/ksudoku ; rm -rf common )
-( cd usr/share/doc/HTML/ru/ksudoku ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kturtle ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kturtle ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/juk ; rm -rf common )
-( cd usr/share/doc/HTML/ru/juk ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/ark ; rm -rf common )
-( cd usr/share/doc/HTML/ru/ark ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/ksysguard ; rm -rf common )
-( cd usr/share/doc/HTML/ru/ksysguard ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kgeography ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kgeography ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kdesu ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kdesu ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kpat ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kpat ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/windowspecific ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/windowspecific ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/fontinst ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/fontinst ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/filetypes ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/filetypes ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/performance ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/performance ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kcontrol/kcmlaunch ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kcontrol/kcmlaunch ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/ktimetracker ; rm -rf common )
+( cd usr/share/doc/HTML/ru/ktimetracker ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/katomic ; rm -rf common )
+( cd usr/share/doc/HTML/ru/katomic ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kleopatra ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kleopatra ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kalgebra ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kalgebra ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcharselect ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcharselect ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/palapeli ; rm -rf common )
-( cd usr/share/doc/HTML/ru/palapeli ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kblackbox ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kblackbox ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kbattleship ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kbattleship ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kdf ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kdf ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/lskat ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/lskat ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kmines ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kmines ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kcron ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kcron ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/ktouch ; rm -rf common )
+( cd usr/share/doc/HTML/ru/ktouch ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kmahjongg ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kmahjongg ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kanagram ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kanagram ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kget ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kget ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kreversi ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kreversi ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/khelpcenter/documentationnotfound ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/khelpcenter/documentationnotfound ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/khelpcenter ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/khelpcenter ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/khelpcenter/glossary ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/khelpcenter/glossary ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kmahjongg ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kmahjongg ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/sonnet ; rm -rf common )
-( cd usr/share/doc/HTML/ru/sonnet ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/katomic ; rm -rf common )
-( cd usr/share/doc/HTML/ru/katomic ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kmousetool ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kmousetool ; ln -sf /usr/share/doc/HTML/ru//common common )
 ( cd usr/share/doc/HTML/ru/kcachegrind ; rm -rf common )
 ( cd usr/share/doc/HTML/ru/kcachegrind ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/kfind ; rm -rf common )
-( cd usr/share/doc/HTML/ru/kfind ; ln -sf /usr/share/doc/HTML/ru//common common )
-( cd usr/share/doc/HTML/ru/ksame ; rm -rf common )
-( cd usr/share/doc/HTML/ru/ksame ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kwordquiz ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kwordquiz ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/krfb ; rm -rf common )
+( cd usr/share/doc/HTML/ru/krfb ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kolf ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kolf ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kfloppy ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kfloppy ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kmines ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kmines ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/konquest ; rm -rf common )
+( cd usr/share/doc/HTML/ru/konquest ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/krdc ; rm -rf common )
+( cd usr/share/doc/HTML/ru/krdc ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kdf ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kdf ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kdebugdialog ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kdebugdialog ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kbruch ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kbruch ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kopete ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kopete ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/rocs ; rm -rf common )
+( cd usr/share/doc/HTML/ru/rocs ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/sonnet ; rm -rf common )
+( cd usr/share/doc/HTML/ru/sonnet ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/konsolekalendar ; rm -rf common )
+( cd usr/share/doc/HTML/ru/konsolekalendar ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/konqueror ; rm -rf common )
+( cd usr/share/doc/HTML/ru/konqueror ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kblackbox ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kblackbox ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kmail ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kmail ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kompare ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kompare ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/ksudoku ; rm -rf common )
+( cd usr/share/doc/HTML/ru/ksudoku ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/ktimer ; rm -rf common )
+( cd usr/share/doc/HTML/ru/ktimer ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kmplot ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kmplot ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/klinkstatus ; rm -rf common )
+( cd usr/share/doc/HTML/ru/klinkstatus ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/kteatime ; rm -rf common )
+( cd usr/share/doc/HTML/ru/kteatime ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/knetattach ; rm -rf common )
+( cd usr/share/doc/HTML/ru/knetattach ; ln -sf /usr/share/doc/HTML/ru//common common )
+( cd usr/share/doc/HTML/ru/knotes ; rm -rf common )
+( cd usr/share/doc/HTML/ru/knotes ; ln -sf /usr/share/doc/HTML/ru//common common )
